@@ -348,6 +348,21 @@ These get replaced with the corresponding values from the project map."
               (.load reader))
             (.getProperty "version")))))
 
+(def ^:private exact-version-error
+  "This project has :exact-lein-version set to \"%s\", while you have %s.")
+
+(defn versions-match? [v1 v2]
+  (let [v1 (string/trim (first (string/split v1 #"-" 2)))
+        v2 (string/trim (first (string/split v2 #"-" 2)))]
+    (= v1 v2)))
+
+(defn- verify-exact-version
+  [{:keys [exact-lein-version]}]
+  (when-not (versions-match? exact-lein-version (leiningen-version))
+    (abort (format exact-version-error
+                   exact-lein-version
+                   (leiningen-version)))))
+
 (defn version-satisfies? [v1 v2]
   (let [v1 (map #(Integer. %) (re-seq #"\d+" (first (string/split v1 #"-" 2))))
         v2 (map #(Integer. %) (re-seq #"\d+" (first (string/split v2 #"-" 2))))]
@@ -401,9 +416,22 @@ Get the latest version of Leiningen at https://leiningen.org or by executing
       (project/init-project)))
 
 (defn- insecure-http-abort [& _]
-  (abort "Tried to use insecure HTTP repository without TLS.
-This is almost certainly a mistake; however in rare cases where it's
-intentional please see `lein help faq` for details."))
+  (let [repo (promise)]
+    (reify org.apache.maven.wagon.Wagon
+      (getRepository [this])
+      (setTimeout [this _])
+      (setInteractive [this _])
+      (addTransferListener [this _])
+      (^void connect [this
+                      ^org.apache.maven.wagon.repository.Repository the-repo
+                      ^org.apache.maven.wagon.authentication.AuthenticationInfo _
+                      ^org.apache.maven.wagon.proxy.ProxyInfoProvider _]
+       (deliver repo the-repo) nil)
+      (get [this resource _]
+        (abort "Tried to use insecure HTTP repository without TLS:\n"
+               (str (.getId @repo) ": " (.getUrl @repo) "\n " resource) "\n"
+               "\nThis is almost certainly a mistake; for details see"
+               "\nhttps://github.com/technomancy/leiningen/blob/master/doc/FAQ.md")))))
 
 (defn -main
   "Command-line entry point."
@@ -415,6 +443,7 @@ intentional please see `lein help faq` for details."))
     (let [project (if (.exists (io/file *cwd* "project.clj"))
                     (project/read (str (io/file *cwd* "project.clj")))
                     (default-project))]
+      (when (:exact-lein-version project) (verify-exact-version project))
       (when (:min-lein-version project) (verify-min-version project))
       (configure-http)
       (resolve-and-apply project raw-args))
