@@ -36,6 +36,11 @@
   ;; relies on features only found in newer Leiningen versions.
   :min-lein-version "2.0.0"
 
+  ;; You can require a specific version of Leiningen. In case of mismatch
+  ;; execution will abort. When versions are compared, suffixes such as
+  ;; "-SNAPSHOT" are dropped.
+  ;; :exact-lein-version "2.8.2"
+
 ;;; Dependencies, Plugins, and Repositories
   ;; Dependencies are listed as [group-id/name version]; in addition
   ;; to keywords supported by Pomegranate, you can use :native-prefix
@@ -78,8 +83,8 @@
   ;; warns when version ranges are present anywhere in the dependency tree,
   ;; but can be set to true to warn for both ranges and overrides, or :abort
   ;; to exit in the case of ranges or overrides. Setting this to :warn or
-  ; :abort will also warn you when plugins or their dependencies
-  ; conflict with libraries used by Leiningen itself.
+  ;; :abort will also warn you when plugins or their dependencies
+  ;; conflict with libraries used by Leiningen itself.
   :pedantic? :abort
   ;; Global exclusions are applied across the board, as an alternative
   ;; to duplication for multiple dependencies with the same excluded libraries.
@@ -382,12 +387,12 @@
                  ;; Only one of #{:nrepl-handler :nrepl-middleware}
                  ;; may be used at a time.
                  ;; Use a different server-side nREPL handler.
-                 :nrepl-handler (clojure.tools.nrepl.server/default-handler)
+                 :nrepl-handler (nrepl.server/default-handler)
                  ;; Add server-side middleware to nREPL stack.
                  :nrepl-middleware [my.nrepl.thing/wrap-amazingness
                                     ;; TODO: link to more detailed documentation.
                                     ;; Middleware without appropriate metadata
-                                    ;; (see clojure.tools.nrepl.middleware/set-descriptor!
+                                    ;; (see nrepl.middleware/set-descriptor!
                                     ;; for details) will simply be appended to the stack
                                     ;; of middleware (rather than ordered based on its
                                     ;; expectations and requirements).
@@ -467,7 +472,12 @@
                   :executions ([:execution [:id "echodir"]
                                 [:goals ([:goal "run"])]
                                 [:phase "verify"]])}]
-                [org.apache.tomcat.maven/tomcat7-maven-plugin "2.1"]]
+                [org.apache.tomcat.maven/tomcat7-maven-plugin "2.1"]
+                [com.google.appengine/appengine-maven-plugin "1.9.68"
+                 ;; Use a list to pass any structure unaltered
+                 (:configuration
+                  [:project "foo"]
+                  [:version "bar"])]]
   ;; Include <scm> tag in generated pom.xml file. All key/value pairs
   ;; appear exactly as configured. If absent, Leiningen will try to
   ;; use information from a .git directory.
